import logging
import bugsnag

class BugsnagHandler(logging.Handler):
    def __init__(self):
        logging.Handler.__init__(self)

        # To enable support for django we try to run the django configure here, but 
        # fail gracefully if we couldnt import or it was not configured properly
        try:
          import bugsnag.django
          bugsnag.django.configure()
        except:
          pass

    def emit(self, record):
        if record.exc_info:
            bugsnag.notify(record.exc_info)



from django.conf import settings

import bugsnag

def configure():
    # Import Bugsnag settings from settings.py
    django_bugsnag_settings = getattr(settings, 'BUGSNAG', {})
    bugsnag.configure(**django_bugsnag_settings)

    # Ignore django 404s by default
    bugsnag.configuration.ignore_classes.append("django.http.Http404")


from celery.signals import task_failure
import bugsnag

def failure_handler(sender, task_id, exception, args, kwargs, traceback, einfo, **kw):
    task = {
        "task_id": task_id,
        "args": args,
        "kwargs": kwargs
    }

    bugsnag.notify(exception, traceback=traceback,
                              context=sender.name,
                              extra_data=task)

def connect_failure_handler():
    """
    Connect the bugsnag failure_handler to the Celery
    task_failure signal
    """
    task_failure.connect(failure_handler, weak=False)


